==> client-3.0.0-sources.jar: com/vesoft/nebula/client/storage/StoragePoolConfig.java <==
/* Copyright (c) 2020 vesoft inc. All rights reserved.
 *
 * This source code is licensed under Apache 2.0 License.
 */

package com.vesoft.nebula.client.storage;

import com.vesoft.nebula.client.graph.data.SSLParam;

public class StoragePoolConfig {
    // The min connections in pool for all addresses
    private int minConnsSize = 0;

    // The max connections in pool for all addresses
    private int maxConnsSize = 10;

    // Socket timeout and Socket connection timeout, unit: millisecond
    private int timeout = 0;

    // The idleTime of the connection, unit: millisecond
    // The connection's idle time more than idleTime, it will be delete
    // 0 means never delete
    private int idleTime = 0;

    // the max total connection in pool for all key
    private int maxTotal = 50;

    // the max total connection in pool for each key
    private int maxTotalPerKey = 10;

    private boolean enableSSL = false;

    private SSLParam sslParam = null;

    public int getMinConnsSize() {
        return minConnsSize;
    }

    public void setMinConnsSize(int minConnsSize) {
        this.minConnsSize = minConnsSize;
    }

    public int getMaxConnsSize() {
        return maxConnsSize;
    }

    public void setMaxConnsSize(int maxConnsSize) {
        this.maxConnsSize = maxConnsSize;
    }

    public int getTimeout() {
        return timeout;
    }

    public void setTimeout(int timeout) {
        this.timeout = timeout;
    }

    public int getIdleTime() {
        return idleTime;
    }

    public void setIdleTime(int idleTime) {
        this.idleTime = idleTime;
    }

    public int getMaxTotal() {
        return maxTotal;
    }

    public void setMaxTotal(int maxTotal) {
        this.maxTotal = maxTotal;
    }

    public int getMaxTotalPerKey() {
        return maxTotalPerKey;
    }

    public void setMaxTotalPerKey(int maxTotalPerKey) {
        this.maxTotalPerKey = maxTotalPerKey;
    }

    public boolean isEnableSSL() {
        return enableSSL;
    }

    public void setEnableSSL(boolean enableSSL) {
        this.enableSSL = enableSSL;
    }

    public SSLParam getSslParam() {
        return sslParam;
    }

    public void setSslParam(SSLParam sslParam) {
        this.sslParam = sslParam;
    }
}

==> client-3.5.0-sources.jar: com/vesoft/nebula/client/storage/StoragePoolConfig.java <==
/* Copyright (c) 2020 vesoft inc. All rights reserved.
 *
 * This source code is licensed under Apache 2.0 License.
 */

package com.vesoft.nebula.client.storage;

import com.vesoft.nebula.client.graph.data.SSLParam;
import java.io.Serializable;

public class StoragePoolConfig implements Serializable {

    private static final long serialVersionUID = 8022858741090966149L;

    // The min connections in pool for all addresses
    private int minConnsSize = 0;

    // The max connections in pool for all addresses
    private int maxConnsSize = 10;

    // Socket timeout and Socket connection timeout, unit: millisecond
    private int timeout = 0;

    // The idleTime of the connection, unit: millisecond
    // The connection's idle time more than idleTime, it will be delete
    // 0 means never delete
    private int idleTime = 0;

    // the max total connection in pool for all key
    private int maxTotal = 50;

    // the max total connection in pool for each key
    private int maxTotalPerKey = 10;

    private boolean enableSSL = false;

    private SSLParam sslParam = null;

    public int getMinConnsSize() {
        return minConnsSize;
    }

    public void setMinConnsSize(int minConnsSize) {
        this.minConnsSize = minConnsSize;
    }

    public int getMaxConnsSize() {
        return maxConnsSize;
    }

    public void setMaxConnsSize(int maxConnsSize) {
        this.maxConnsSize = maxConnsSize;
    }

    public int getTimeout() {
        return timeout;
    }

    public void setTimeout(int timeout) {
        this.timeout = timeout;
    }

    public int getIdleTime() {
        return idleTime;
    }

    public void setIdleTime(int idleTime) {
        this.idleTime = idleTime;
    }

    public int getMaxTotal() {
        return maxTotal;
    }

    public void setMaxTotal(int maxTotal) {
        this.maxTotal = maxTotal;
    }

    public int getMaxTotalPerKey() {
        return maxTotalPerKey;
    }

    public void setMaxTotalPerKey(int maxTotalPerKey) {
        this.maxTotalPerKey = maxTotalPerKey;
    }

    public boolean isEnableSSL() {
        return enableSSL;
    }

    public void setEnableSSL(boolean enableSSL) {
        this.enableSSL = enableSSL;
    }

    public SSLParam getSslParam() {
        return sslParam;
    }

    public void setSslParam(SSLParam sslParam) {
        this.sslParam = sslParam;
    }
}
